Toon.EncodeError exception (toon v0.3.0)
View SourceException raised when encoding fails.
This exception is raised when the encoder encounters an error while converting Elixir data structures to TOON format.
Summary
Functions
Creates a new EncodeError.